@@ -23,13 +23,15 @@
 #include <KPropertiesDialog>
 
 #include <QDBusConnection>
+#include <QDBusConnectionInterface>
 
 DBusInterface::DBusInterface() :
     QObject()
 {
-    QDBusConnection::sessionBus().registerService(QStringLiteral("org.freedesktop.FileManager1"));
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/org/freedesktop/FileManager1"), this,
             QDBusConnection::ExportScriptableContents | QDBusConnection::ExportAdaptors);
+    QDBusConnection::sessionBus().interface()->registerService(QStringLiteral("org.freedesktop.FileManager1"),
+                                                               QDBusConnectionInterface::QueueService);
 }
 
 void DBusInterface::ShowFolders(const QStringList& uriList, const QString& startUpId)
