@@ -25,6 +25,7 @@
 #include <KIO/PreviewJob>
 #include <KJobWidgets>
 #include <KToolTipWidget>
+#include <KIconLoader>
 
 #include <QApplication>
 #include <QDesktopWidget>
@@ -34,6 +35,15 @@
 #include <QTimer>
 #include <QWindow>
 
+class IconLoaderSingleton {
+public:
+    IconLoaderSingleton() = default;
+
+    KIconLoader self;
+};
+
+Q_GLOBAL_STATIC(IconLoaderSingleton, iconLoader)
+
 ToolTipManager::ToolTipManager(QWidget* parent) :
     QObject(parent),
     m_showToolTipTimer(nullptr),
@@ -82,11 +92,10 @@ void ToolTipManager::showToolTip(const KFileItem& item, const QRectF& itemRect,
     // Only start the retrieving of the content, when the mouse has been over this
     // item for 200 milliseconds. This prevents a lot of useless preview jobs and
     // meta data retrieval, when passing rapidly over a lot of items.
-    delete m_fileMetaDataWidget;
-    m_fileMetaDataWidget = new DolphinFileMetaDataWidget();
-    connect(m_fileMetaDataWidget, &DolphinFileMetaDataWidget::metaDataRequestFinished,
+    m_fileMetaDataWidget.reset(new DolphinFileMetaDataWidget());
+    connect(m_fileMetaDataWidget.data(), &DolphinFileMetaDataWidget::metaDataRequestFinished,
             this, &ToolTipManager::slotMetaDataRequestFinished);
-    connect(m_fileMetaDataWidget, &DolphinFileMetaDataWidget::urlActivated,
+    connect(m_fileMetaDataWidget.data(), &DolphinFileMetaDataWidget::urlActivated,
             this, &ToolTipManager::urlActivated);
 
     m_contentRetrievalTimer->start();
@@ -168,8 +177,13 @@ void ToolTipManager::previewFailed()
     if (!m_toolTipRequested) {
         return;
     }
-
-    const QPixmap pixmap = QIcon::fromTheme(m_item.iconName()).pixmap(128, 128);
+    QPalette pal;
+    for (auto state : { QPalette::Active, QPalette::Inactive, QPalette::Disabled }) {
+        pal.setBrush(state, QPalette::WindowText, pal.toolTipText());
+        pal.setBrush(state, QPalette::Window, pal.toolTipBase());
+    }
+    iconLoader->self.setCustomPalette(pal);
+    const QPixmap pixmap = KDE::icon(m_item.iconName(), &iconLoader->self).pixmap(128, 128);
     m_fileMetaDataWidget->setPreview(pixmap);
     if (!m_showToolTipTimer->isActive()) {
         showToolTip();
@@ -209,7 +223,7 @@ void ToolTipManager::showToolTip()
     if (!m_tooltipWidget) {
         m_tooltipWidget.reset(new KToolTipWidget());
     }
-    m_tooltipWidget->showBelow(m_itemRect, m_fileMetaDataWidget, m_transientParent);
+    m_tooltipWidget->showBelow(m_itemRect, m_fileMetaDataWidget.data(), m_transientParent);
     m_toolTipRequested = false;
 }
 
